@@ -6,14 +6,9 @@ import click
 from click_option_group import MutuallyExclusiveOptionGroup
 
 from . import __version__
-from .core import (
-    CheckHashLineError,
-    HashFileReader,
-    HashFileWriter,
-    check_hash_line,
-    generate_hash_line,
-)
+from .core import CheckHashLineError, HashFileReader, HashFileWriter, check_hash_line, generate_hash_line
 from .hasher import Hasher
+from .utils.click import Command
 from .utils.glob import glob_filters
 
 
@@ -226,11 +221,7 @@ def gethashcli(cmdname, hashname, suffix, **ignored):
         path_format = MutuallyExclusiveOptionGroup("Path Format")
         output_mode = MutuallyExclusiveOptionGroup("Output Mode")
 
-        @click.command(
-            cmdname,
-            context_settings=dict(help_option_names=["-h", "--help"]),
-            no_args_is_help=True,
-        )
+        @click.command(cmdname, cls=Command, no_args_is_help=True)
         @click.argument("files", nargs=-1)
         @click.option(
             "-c",
@@ -242,8 +233,7 @@ def gethashcli(cmdname, hashname, suffix, **ignored):
             "-d",
             "--dir",
             is_flag=True,
-            help="Allow checksum for directories. "
-            "Just xor each checksum of files in a given directory.",
+            help="Allow checksum for directories. Just xor each checksum of files in a given directory.",
         )
         @click.option(
             "--suffix",
@@ -277,9 +267,7 @@ def gethashcli(cmdname, hashname, suffix, **ignored):
             is_flag=True,
             help="Update mtime of hash files to the same as data files.",
         )
-        @path_format.option(
-            "-i", "--inplace", is_flag=True, help="Use basename in checksum files."
-        )
+        @path_format.option("-i", "--inplace", is_flag=True, help="Use basename in checksum files.")
         @path_format.option(
             "-z",
             "--root",
@@ -304,11 +292,9 @@ def gethashcli(cmdname, hashname, suffix, **ignored):
         @click.option("--no-stdout", is_flag=True, help="Do not output to stdout.")
         @click.option("--no-stderr", is_flag=True, help="Do not output to stderr.")
         @click.option("--tqdm-ascii", type=click.BOOL, default=False, show_default=True)
-        @click.option(
-            "--tqdm-disable", type=click.BOOL, default=False, show_default=True
-        )
+        @click.option("--tqdm-disable", type=click.BOOL, default=False, show_default=True)
         @click.option("--tqdm-leave", type=click.BOOL, default=False, show_default=True)
-        @click.version_option(__version__, prog_name=cmdname)
+        @click.version_option(__version__, "-V", "--version", prog_name=cmdname)
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             return func(*args, **kwargs)
