@@ -17,8 +17,8 @@ __all__ = [
 
 def _check_int(obj: object, name: str) -> None:
     if not isinstance(obj, int):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be int, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be int, not {tn}")
 
 
 def _check_int_opt(obj: object, name: str, default: object = None) -> Any:
@@ -26,15 +26,15 @@ def _check_int_opt(obj: object, name: str, default: object = None) -> Any:
         return default
 
     if not isinstance(obj, int):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be int or None, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be int or None, not {tn}")
     return obj
 
 
 def _check_float(obj: object, name: str) -> None:
     if not isinstance(obj, float):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be float, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be float, not {tn}")
 
 
 def _check_float_opt(obj: object, name: str, default: object = None) -> Any:
@@ -42,15 +42,15 @@ def _check_float_opt(obj: object, name: str, default: object = None) -> Any:
         return default
 
     if not isinstance(obj, float):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be float or None, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be float or None, not {tn}")
     return obj
 
 
 def _check_str(obj: object, name: str) -> None:
     if not isinstance(obj, str):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be str, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be str, not {tn}")
 
 
 def _check_str_opt(obj: object, name: str, default: object = None) -> Any:
@@ -58,15 +58,15 @@ def _check_str_opt(obj: object, name: str, default: object = None) -> Any:
         return default
 
     if not isinstance(obj, str):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be str or None, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be str or None, not {tn}")
     return obj
 
 
 def _check_bytes(obj: object, name: str) -> None:
     if not isinstance(obj, (bytes, bytearray, memoryview)):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be bytes-like, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be bytes-like, not {tn}")
 
 
 def _check_bytes_opt(obj: object, name: str, default: object = None) -> Any:
@@ -74,15 +74,15 @@ def _check_bytes_opt(obj: object, name: str, default: object = None) -> Any:
         return default
 
     if not isinstance(obj, (bytes, bytearray, memoryview)):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be bytes-like or None, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be bytes-like or None, not {tn}")
     return obj
 
 
 def _check_bytes_w(obj: object, name: str) -> None:
     if not (isinstance(obj, bytearray) or _is_writable_memoryview(obj)):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be writable bytes-like, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be writable bytes-like, not {tn}")
 
 
 def _check_bytes_w_opt(obj: object, name: str, default: object = None) -> Any:
@@ -90,10 +90,10 @@ def _check_bytes_w_opt(obj: object, name: str, default: object = None) -> Any:
         return default
 
     if not (isinstance(obj, bytearray) or _is_writable_memoryview(obj)):
-        t = type(obj).__name__
-        raise TypeError(f"{name} must be writable bytes-like or None, not {t}")
+        tn = type(obj).__name__
+        raise TypeError(f"{name} must be writable bytes-like or None, not {tn}")
     return obj
 
 
-def _is_writable_memoryview(obj):
+def _is_writable_memoryview(obj: object) -> bool:
     return isinstance(obj, memoryview) and not obj.readonly
